package com.jiuqi.util;

import java.util.ArrayList;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/IntMatrix.class */
public final class IntMatrix {
    private int colCount = 0;
    private int rowCount = 0;
    private ArrayList rowList = new ArrayList(0);

    public IntMatrix() {
    }

    public IntMatrix(int colCount, int rowCount) {
        reset(colCount, rowCount);
    }

    public void clear() {
        this.rowList.clear();
        this.colCount = 0;
        this.rowCount = 0;
    }

    public void reset(int newColCount, int newRowCount) {
        clear();
        setColCount(newColCount);
        setRowCount(newRowCount);
    }

    public int getColCount() {
        return this.colCount;
    }

    public void setColCount(int newColCount) {
        if (this.colCount == newColCount) {
            return;
        }
        int count = this.colCount <= newColCount ? this.colCount : newColCount;
        for (int i = 0; i < this.rowCount; i++) {
            int[] oldRow = (int[]) this.rowList.get(i);
            int[] newRow = new int[newColCount];
            for (int j = 0; j < count; j++) {
                newRow[j] = oldRow[j];
            }
            this.rowList.set(i, newRow);
        }
        this.colCount = newColCount;
    }

    public int getRowCount() {
        return this.rowCount;
    }

    public void setRowCount(int newRowCount) {
        if (this.rowCount == newRowCount) {
            return;
        }
        for (int i = this.rowCount - 1; i >= newRowCount; i--) {
            this.rowList.remove(i);
        }
        for (int i2 = this.rowCount; i2 < newRowCount; i2++) {
            this.rowList.add(new int[this.colCount]);
        }
        this.rowCount = newRowCount;
    }

    public int get(int x, int y) {
        int[] aRow = (int[]) this.rowList.get(y);
        return aRow[x];
    }

    public void set(int x, int y, int value) {
        int[] aRow = (int[]) this.rowList.get(y);
        aRow[x] = value;
    }

    public void insertCol(int index) {
        for (int i = 0; i < this.rowCount; i++) {
            int[] oldRow = (int[]) this.rowList.get(i);
            int[] newRow = new int[this.colCount + 1];
            for (int j = 0; j < index; j++) {
                newRow[j] = oldRow[j];
            }
            for (int j2 = index; j2 < this.colCount; j2++) {
                newRow[j2 + 1] = oldRow[j2];
            }
        }
        this.colCount++;
    }

    public void deleteCol(int index) {
        for (int i = 0; i < this.rowCount; i++) {
            int[] oldRow = (int[]) this.rowList.get(i);
            int[] newRow = new int[this.colCount - 1];
            for (int j = 0; j < index; j++) {
                newRow[j] = oldRow[j];
            }
            for (int j2 = index + 1; j2 < this.colCount; j2++) {
                newRow[j2 - 1] = oldRow[j2];
            }
        }
        this.colCount--;
    }

    public void exchangeCol(int index1, int index2) {
        for (int i = 0; i < this.rowCount; i++) {
            int[] aRow = (int[]) this.rowList.get(i);
            int T = aRow[index1];
            aRow[index1] = aRow[index2];
            aRow[index2] = T;
        }
    }

    public void moveCol(int index1, int index2) {
        if (index1 == index2) {
            return;
        }
        for (int i = 0; i < this.rowCount; i++) {
            int[] aRow = (int[]) this.rowList.get(i);
            int T = aRow[index1];
            if (index1 > index2) {
                for (int j = index1 - 1; j >= index2; j--) {
                    aRow[j + 1] = aRow[j];
                }
            } else if (index1 < index2) {
                for (int j2 = index1 + 1; j2 < index2; j2++) {
                    aRow[j2 - 1] = aRow[j2];
                }
            }
            aRow[index2] = T;
        }
    }

    public void insertRow(int index) {
        this.rowList.add(index, new int[this.colCount]);
        this.rowCount++;
    }

    public void deleteRow(int index) {
        this.rowList.remove(index);
        this.rowCount--;
    }

    public void exchangeRow(int index1, int index2) {
        int[] aRow = (int[]) this.rowList.get(index1);
        this.rowList.set(index1, this.rowList.get(index2));
        this.rowList.set(index2, aRow);
    }

    public void moveRow(int index1, int index2) {
        int[] aRow = (int[]) this.rowList.get(index1);
        if (index1 > index2) {
            for (int i = index1 - 1; i >= index2; i--) {
                this.rowList.set(i + 1, this.rowList.get(i));
            }
        } else if (index1 < index2) {
            for (int i2 = index1 + 1; i2 < index2; i2++) {
                this.rowList.set(i2 - 1, this.rowList.get(i2));
            }
        }
        this.rowList.set(index2, aRow);
    }
}
